@@ -7,7 +7,8 @@ LOCAL_HOME_PATH="/local/home/$PAM_USER_UID"
 
 umask 0022
 
-/bin/mkdir -p "/local/home"
+# Try to create /local/home if we are root
+[ "$UID" != "0" ] || /bin/mkdir -p "/local/home"
 
 umask 0077
 /bin/mkdir -p "$LOCAL_HOME_PATH"
